SpecialEventDisplay

Struct SpecialEventDisplay 

pub struct SpecialEventDisplay<Dpy: ?Sized> { /* private fields */ }
A special type of Display that provides queues for special events.

See the module level documentation for more information.

Implementations

Source

impl<Dpy> SpecialEventDisplay<Dpy>

pub fn into_inner(self) -> Dpy

Get the inner display type.

Source

impl<Dpy: ?Sized> SpecialEventDisplay<Dpy>

pub fn create_special_event_queue( &mut self, classifier: impl FnMut(&Event) -> bool + Send + Sync + 'static, ) -> usize

Create a new special event queue with the given classifier.

Returns the key to be used to poll the event queue.

pub fn remove_special_event_queue(&mut self, key: usize)

Remove the special event queue with the given key.

Source

impl<Dpy: DisplayBase + ?Sized> SpecialEventDisplay<Dpy>

pub fn poll_for_special_event(&mut self, key: usize) -> Result<Option<Event>>

Poll for a special event for the given queue.

Source

impl<Dpy: Display + ?Sized> SpecialEventDisplay<Dpy>

pub fn wait_for_special_event(&mut self, key: usize) -> Result<Event>

Wait for a special event from the given queue.

Source

impl<Dpy: AsyncDisplay + ?Sized> SpecialEventDisplay<Dpy>

pub async fn wait_for_special_event_async( &mut self, key: usize, ) -> Result<Event>

Wait for a speical event from the given queue.