Implements the “special events” pattern for breadx.
Some extensions to X11 mandate a pattern known as “special events”, where
certain events are sorted into queues for libraries to process. It’s only
ever used in a couple of extensions, and checking for them is not idiomatic
to do on the hot path for event processing. Therefore, breadx does not
do it by default.
This module provides a way to process special events. The SpecialEventDisplay
type is a wrapper around a Display that provides queues for special events.
Queues can be registered or deregistered, and then polled or waited on, similar
to regular events.
SpecialEventDisplay can be created through its universal From implementation.
Structs
- Special
Event Display - A special type of
Displaythat provides queues for special events.