pub struct SpecialEventDisplay<Dpy: ?Sized> { /* private fields */ }Expand description
A special type of Display that provides queues for special events.
See the module level documentation for more information.
Implementations
Sourceimpl<Dpy> SpecialEventDisplay<Dpy>
impl<Dpy> SpecialEventDisplay<Dpy>
Sourcepub fn into_inner(self) -> Dpy
pub fn into_inner(self) -> Dpy
Get the inner display type.
Sourceimpl<Dpy: ?Sized> SpecialEventDisplay<Dpy>
impl<Dpy: ?Sized> SpecialEventDisplay<Dpy>
Sourcepub fn create_special_event_queue(
&mut self,
classifier: impl FnMut(&Event) -> bool + Send + Sync + 'static,
) -> usize
pub fn create_special_event_queue( &mut self, classifier: impl FnMut(&Event) -> bool + Send + Sync + 'static, ) -> usize
Create a new special event queue with the given classifier.
Returns the key to be used to poll the event queue.
Sourcepub fn remove_special_event_queue(&mut self, key: usize)
pub fn remove_special_event_queue(&mut self, key: usize)
Remove the special event queue with the given key.
Sourceimpl<Dpy: DisplayBase + ?Sized> SpecialEventDisplay<Dpy>
impl<Dpy: DisplayBase + ?Sized> SpecialEventDisplay<Dpy>
Sourceimpl<Dpy: Display + ?Sized> SpecialEventDisplay<Dpy>
impl<Dpy: Display + ?Sized> SpecialEventDisplay<Dpy>
Sourcepub fn wait_for_special_event(&mut self, key: usize) -> Result<Event>
pub fn wait_for_special_event(&mut self, key: usize) -> Result<Event>
Wait for a special event from the given queue.
Sourceimpl<Dpy: AsyncDisplay + ?Sized> SpecialEventDisplay<Dpy>
impl<Dpy: AsyncDisplay + ?Sized> SpecialEventDisplay<Dpy>
Sourcepub async fn wait_for_special_event_async(
&mut self,
key: usize,
) -> Result<Event>
pub async fn wait_for_special_event_async( &mut self, key: usize, ) -> Result<Event>
Wait for a speical event from the given queue.